@@ -191,7 +191,7 @@ def getStitchPoolClass(
     cls = StitchPool
     cls.domain = domain
     cls.redis_client = attach_stitch_lua_scripts(redis_client=redis_client)
-    cls.django_stitch_model = django_stitch_pool_model
+    cls.django_stitch_pool_model = django_stitch_pool_model
     cls.django_connection_tuple = django_connection_tuple
     cls.user_ttl = user_ttl
     cls.user_data_ttl_margin = user_data_ttl_margin
