@@ -508,7 +508,7 @@ class LuaScripts(object):
                     table.insert(stitch_key_result, 'user_ids')
                     table.insert(stitch_key_result, user_ids)
 
-                    recent_check = redis.call('GET', el .. ARGV[2])
+                    local recent_check = redis.call('GET', el .. ARGV[2])
                     table.insert(stitch_key_result, 'recent_check')
                     table.insert(stitch_key_result, recent_check)
 
